@@ -1,3 +1,11 @@
+"""
+http://grouper.ieee.org/groups/1788/PositionPapers/ARITHYY.pdf
+
+http://grouper.ieee.org/groups/1788/PositionPapers/overlapping.pdf
+
+www.wikipedia.org/Interval
+"""
+
 # -*- coding: utf-8 -*-
 from datetime import datetime, date, timedelta
 from decimal import Decimal
@@ -17,7 +25,7 @@ __all__ = (
 )
 
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 
 def is_number(number):
@@ -66,7 +74,9 @@ def canonicalize(interval, lower_inc=True, upper_inc=False):
 def coerce_interval(func):
     def wrapper(self, arg):
         try:
-            return func(self, self.__class__(arg))
+            if arg is not None:
+                arg = self.__class__(arg)
+            return func(self, arg)
         except IntervalException:
             return NotImplemented
     return wrapper
@@ -373,13 +383,47 @@ class AbstractInterval(object):
         """
         Defines the substraction operator.
 
-        [a, b] − [c, d] = [a − d, b − c]
+        [a, b] - [c, d] = [a - d, b - c]
         """
         return self.__class__([
             self.lower - other.upper,
             self.upper - other.lower
         ])
 
+    @coerce_interval
+    def glb(self, other):
+        """
+        Return the greatest lower bound for given intervals.
+
+        :param other: AbstractInterval instance
+        """
+        return self.__class__(
+            min(self.lower, other.lower),
+            min(self.upper, other.upper),
+            lower_inc=self.lower_inc if self < other else other.lower_inc,
+            upper_inc=self.upper_inc if self > other else other.upper_inc,
+        )
+
+    @coerce_interval
+    def lub(self, other):
+        """
+        Return the least upper bound for given intervals.
+
+        :param other: AbstractInterval instance
+        """
+        return self.__class__(
+            max(self.lower, other.lower),
+            max(self.upper, other.upper),
+            lower_inc=self.lower_inc if self < other else other.lower_inc,
+            upper_inc=self.upper_inc if self > other else other.upper_inc,
+        )
+
+    def inf(self, other):
+        raise NotImplementedError
+
+    def sup(self, other):
+        raise NotImplementedError
+
     @coerce_interval
     def __rsub__(self, other):
         return self.__class__([
